<?php

namespace App\Http\Controllers;

use App\Http\Requests\CreateProductRequest;
use App\Http\Requests\UpdateProductRequest;
use App\Models\Aspect;
use App\Models\Line;
use App\Models\Position;
use App\Models\Product;
use Illuminate\Http\Request;

class ProductController extends Controller
{
    function index()
    {
        $products = Product::all();
        return view('product.index', compact('products'));
    }
    function storage(CreateProductRequest $request)
    {
        $product = Product::create(['name' => $request->name,'line_id' => NULL]);
        return response()->json($product);
    }

    function update(UpdateProductRequest $request)
    {
        $product = Product::find($request->id);
        $product->name = $request->name;
        $product->save();
        $products=Product::with('line','aspect')->get();
        return response()->json([
            'products' => $products
        ]);
    }

    function delete(Request $request)
    {
        Product::destroy($request->id);
        return response()->json();
    }
    function get(Request $request)
    {
        $product = Product::find($request->product);
        $lines=Line::all();
        return response()->json([
            'lines' =>  $lines
        ]);
    }
    function assignament(Request $request)
    {
        $product = Product::find($request->product);
        $product->line_id=$request->line;
        $product->save();
        $products=Product::with('line','aspect')->get();
        return response()->json([
            'products' => $products,
            'lines' => Line::all()
        ]);
    }
    function desassignament(Request $request)
    {
        $product = Product::find($request->product);
        $product->line_id=null;
        $product->save();
        $products=Product::with('line','aspect')->get();
        return response()->json([
            'products' => $products,
            'lines' => Line::all()
        ]);
    }
    function getaspect()
    {
        $aspects=Aspect::all();
        return response()->json([
            'aspects' =>  $aspects
        ]);
    }
    function assignamentaspect(Request $request)
    {
        $product = Product::find($request->product);
        $product->aspect_id=$request->aspect;
        $product->save();
        $products=Product::with('line','aspect')->get();
        return response()->json([
            'products' => $products
        ]);
    }
    function dessignamentaspect(Request $request)
    {
        $product = Product::find($request->product);
        $product->aspect_id=null;
        $product->save();
        $products=Product::with('line','aspect')->get();
        return response()->json([
            'products' => $products
        ]);
    }
    function getposition(Request $request) 
    {
        $product=Product::find($request->product);
        $positions=Position::wherenotIn('id',$product->positions->pluck('id'))->get();
        return response()->json([
            'positions' => $positions
        ]);
    }
    function assignamentposition(Request $request)
    {
        $product=Product::find($request->product);
        $product->positions()->attach($request->position);
        return response()->json();
    }
    function pregetposition(Request $request)
    {
        $product=Product::find($request->product);
        
        return response()->json([
            'positions' => $product->positions
        ]);
    }
    function dessignamentposition(Request $request)
    {
        $product=Product::find($request->product);
        $product->positions()->detach($request->position);
        return response()->json();
    }
}
