<?php

namespace App\Http\Requests;

use Illuminate\Contracts\Validation\Validator;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Exceptions\HttpResponseException;

class CreateSignatureRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }
    
    protected function failedValidation(Validator $validator)
    {
        throw new HttpResponseException(response()->json(['errors'=>$validator->errors(),200]));
    }
    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        return [
            'signature' => 'required',
            'product' => 'required|numeric|exists:products,id',
            'operator' => 'required|numeric|exists:operators,id'
        ];
    }
    public function messages()
    {
        return [
            'signature.required' => 'Es obligatorio firmar.',
            
            'product.required' => 'Es obligatorio poner un producto.',
            'product.exits' => 'Es obligatorio que el producto exista.',
            'product.numeric' => 'El formato del producto no es correcto.',

            'operator.required' => 'Es obligatorio poner un operador.',
            'operator.exists' => 'Es obligatorio que el operador exista.',
            'operator.numeric' => 'El formato del operador no es correcto.',
        ];
    }
}
