<?php

namespace App\Http\Requests;

use Illuminate\Contracts\Validation\Validator;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Exceptions\HttpResponseException;

class CreateTurnRequest extends FormRequest
{
    public function authorize()
    {
        return true;
    }
    
    protected function failedValidation(Validator $validator)
    {
        throw new HttpResponseException(response()->json(['errors'=>$validator->errors(),200]));
    }
    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        return [
            'name' => 'required|string|unique:turns,name',
            'start' => 'required|date_format:H:i|unique:turns,start',
            'end' => 'required|date_format:H:i|unique:turns,end'
        ];
    }
    public function messages()
    {
        return [
            'name.required' => 'Es obligatorio poner un nombre.',
            'name.string' => 'El formato del nombre no es correcto.',
            'name.unique' => 'El nombre del turno no puede existir.',

            'start.required' => 'Es obligatorio poner una hora de inicio.',
            'start.date_format' => 'El formato del inicio del turno no es correcto.',
            'start.unique' => 'La hora del turno no puede existir.',

            'end.required' => 'Es obligatorio poner una hora de fin.',
            'end.date_format' => 'El formato del fin del turno no es correcto.',
            'end.unique' => 'El nombre del turno no puede existir.',
        ];
    }
}
