<?php

namespace App\Http\Requests;

use Illuminate\Contracts\Validation\Validator;
use Illuminate\Foundation\Http\FormRequest;
use Illuminate\Http\Exceptions\HttpResponseException;

class UpdateParameterRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }
    
    protected function failedValidation(Validator $validator)
    {
        throw new HttpResponseException(response()->json(['errors'=>$validator->errors(),200]));
    }
    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        return [
            'id' => 'required|numeric|exists:parameters,id',
            'name' => 'required|string|unique:parameters,name'
        ];
    }
    public function messages()
    {
        return [
            'name.required' => 'Es obligatorio poner un nombre.',
            'name.string' => 'El formato del nombre no es correcto.',
            'name.unique' => 'El nombre del parametro no puede existir.',

            'id.required' => 'Es obligatorio poner un parametro.',
            'id.numeric' => 'El formato del parametro no es correcto.',
            'id.exits' => 'El parametro tiene que existir.',
        ];
    }
}
